@@ -79,16 +79,16 @@ G_GNUC_EXTENSION typedef unsigned long long guint64;
 #define GLIB_SIZEOF_SIZE_T 4
 #define GLIB_SIZEOF_SSIZE_T 4
 
-typedef signed long gssize;
-typedef unsigned long gsize;
-#define G_GSIZE_MODIFIER "l"
-#define G_GSSIZE_MODIFIER "l"
-#define G_GSIZE_FORMAT "lu"
-#define G_GSSIZE_FORMAT "li"
+typedef signed int gssize;
+typedef unsigned int gsize;
+#define G_GSIZE_MODIFIER ""
+#define G_GSSIZE_MODIFIER ""
+#define G_GSIZE_FORMAT "u"
+#define G_GSSIZE_FORMAT "i"
 
-#define G_MAXSIZE	G_MAXULONG
-#define G_MINSSIZE	G_MINLONG
-#define G_MAXSSIZE	G_MAXLONG
+#define G_MAXSIZE	G_MAXUINT
+#define G_MINSSIZE	G_MININT
+#define G_MAXSSIZE	G_MAXINT
 
 typedef gint64 goffset;
 #define G_MINOFFSET	G_MININT64
@@ -114,8 +114,8 @@ typedef unsigned int guintptr;
 #define G_GUINTPTR_FORMAT       "u"
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 80
-#define GLIB_MICRO_VERSION 4
+#define GLIB_MINOR_VERSION 82
+#define GLIB_MICRO_VERSION 2
 
 #define G_OS_UNIX
 
